// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef QGPGME_VERSION_H
#define QGPGME_VERSION_H

#define QGPGME_VERSION_STRING "2.2.0"
#define QGPGME_VERSION_MAJOR 2
#define QGPGME_VERSION_MINOR 2
#define QGPGME_VERSION_PATCH 0
#define QGPGME_VERSION ((2<<16)|(2<<8)|(0))

#endif
